dofile_once("data/scripts/lib/utilities.lua")
dofile_once("data/scripts/lib/mod_settings.lua")

local mod_id = "player_ghost"
mod_settings_version = 1

local settings = {
  max_amount_saved = {
    description = "Max wands stored",
    default = 30,
    min = 1,
    max = 50,
  },
  spawn_chance_percent = {
    description = "Spawn probability % (per spawnpoint)",
    default = 20,
    min = 1,
    max = 100,
  },
  wands_required_count = {
    description = "Number of wands required to spawn",
    default = 5,
    min = 1,
    max = 30,
  },
}

local setting_count = 0
local stored_wand_count -- Gets calculated in ModSettingsUpdate

for k, v in pairs(settings) do
  setting_count = setting_count + 1
end

local function get_setting_id(name)
	return mod_id .. "." .. name
end

function ModSettingsGuiCount()
	return 1
end

function ModSettingsUpdate(init_scope)
  for setting, props in pairs(settings) do
    ModSettingSetNextValue(get_setting_id(setting), props.default, true)
    local next_value = ModSettingGetNextValue(get_setting_id(setting))
    if next_value ~= nil then
      ModSettingSet(get_setting_id(setting), next_value)
    end
  end

  if not stored_wand_count then
    stored_wand_count = 0
    for i=1, ModSettingGetNextValue(get_setting_id("max_amount_saved")) do
      if ModSettingGet("player_ghost.wand"..i) then
        stored_wand_count = stored_wand_count + 1
      end
    end
  end

  ModSettingSet(get_setting_id("_version"), mod_settings_version)
end

function ModSettingsGui( gui, in_main_menu )
	local id = 1
	local function get_id()
		id = id + 1
		return id
	end

  GuiLayoutBeginHorizontal(gui, 0, 0)

  -- Render labels
  GuiLayoutBeginVertical(gui, 0, 0)
  for setting, props in pairs(settings) do
    GuiText(gui, 0, 0, props.description)
  end
  GuiLayoutEnd(gui)

  -- Render sliders
  GuiLayoutBeginVertical(gui, 0, 0)
  for setting, props in pairs(settings) do
    local next_value = ModSettingGetNextValue(get_setting_id(setting))
    local new_value = GuiSlider(gui, get_id(), 10, 2, "", next_value, props.min, props.max, props.default, 1, " " or setting.value_display_formatting, 80)
    new_value = math.floor(new_value)
    GuiLayoutAddVerticalSpacing(gui, 1)
    if new_value ~= next_value then
      ModSettingSetNextValue(get_setting_id(setting), new_value, false)
    end
  end
  GuiLayoutEnd(gui)

  -- Render values
  GuiLayoutBeginVertical(gui, 0, 0)
  for setting, props in pairs(settings) do
    local next_value = ModSettingGetNextValue(get_setting_id(setting))
    GuiText(gui, 20, 0, tostring(next_value))
  end
  GuiLayoutEnd(gui)
  GuiLayoutEnd(gui)

  -- Need to do this because the game doesn't count how many items are in the vertical group
  for i=2, setting_count do
    GuiText(gui, 0, 0, " ")
  end
  if GuiButton(gui, get_id(), 0, 0, "Delete all saved wands (" .. stored_wand_count .. ")") then
    for i=1, 30 do
      stored_wand_count = 0
      ModSettingRemove(get_setting_id("wand"..i))
    end
  end
end
